Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Writer ¶ added in v0.2.0
type Writer struct {
// contains filtered or unexported fields
}
func New ¶
New creates a new buffered writer that implements io.Write. The writer accumulates input data in a buffer with size of size, until it is filled up or delayFlush time is pass, and then writes to underlying writer w.
Click to show internal directories.
Click to hide internal directories.